==> Signal-Desktop-6.47.1.tar.gz: Signal-Desktop-6.47.1/ts/components/conversation/contactUtil.tsx <==
// Copyright 2019 Signal Messenger, LLC
// SPDX-License-Identifier: AGPL-3.0-only

import React from 'react';
import classNames from 'classnames';

import { Avatar, AvatarBlur } from '../Avatar';
import { Spinner } from '../Spinner';

import type { LocalizerType } from '../../types/Util';
import { AvatarColors } from '../../types/Colors';
import type { EmbeddedContactType } from '../../types/EmbeddedContact';
import { getName } from '../../types/EmbeddedContact';

export function renderAvatar({
  contact,
  i18n,
  size,
  direction,
}: {
  contact: EmbeddedContactType;
  i18n: LocalizerType;
  size: 28 | 52 | 80;
  direction?: 'outgoing' | 'incoming';
}): JSX.Element {
  const { avatar } = contact;

  const avatarPath = avatar && avatar.avatar && avatar.avatar.path;
  const pending = avatar && avatar.avatar && avatar.avatar.pending;
  const title = getName(contact) || '';
  const spinnerSvgSize = size < 50 ? 'small' : 'normal';
  const spinnerSize = size < 50 ? '24px' : undefined;

  if (pending) {
    return (
      <div className="module-embedded-contact__spinner-container">
        <Spinner
          svgSize={spinnerSvgSize}
          size={spinnerSize}
          direction={direction}
        />
      </div>
    );
  }

  return (
    <Avatar
      acceptedMessageRequest={false}
      avatarPath={avatarPath}
      badge={undefined}
      blur={AvatarBlur.NoBlur}
      color={AvatarColors[0]}
      conversationType="direct"
      i18n={i18n}
      isMe
      title={title}
      sharedGroupNames={[]}
      size={size}
    />
  );
}

export function renderName({
  contact,
  isIncoming,
  module,
}: {
  contact: EmbeddedContactType;
  isIncoming: boolean;
  module: string;
}): JSX.Element {
  return (
    <div
      className={classNames(
        `module-${module}__contact-name`,
        isIncoming ? `module-${module}__contact-name--incoming` : null
      )}
    >
      {getName(contact)}
    </div>
  );
}

export function renderContactShorthand({
  contact,
  isIncoming,
  module,
}: {
  contact: EmbeddedContactType;
  isIncoming: boolean;
  module: string;
}): JSX.Element {
  const { number: phoneNumber, email } = contact;
  const firstNumber = phoneNumber && phoneNumber[0] && phoneNumber[0].value;
  const firstEmail = email && email[0] && email[0].value;

  return (
    <div
      className={classNames(
        `module-${module}__contact-method`,
        isIncoming ? `module-${module}__contact-method--incoming` : null
      )}
    >
      {firstNumber || firstEmail}
    </div>
  );
}

==> Signal-Desktop-7.47.0.tar.gz: Signal-Desktop-7.47.0/ts/components/conversation/contactUtil.tsx <==
// Copyright 2019 Signal Messenger, LLC
// SPDX-License-Identifier: AGPL-3.0-only

import React from 'react';
import classNames from 'classnames';
import type { ReadonlyDeep } from 'type-fest';

import { Avatar, AvatarBlur } from '../Avatar';
import { AvatarColors } from '../../types/Colors';
import { getName } from '../../types/EmbeddedContact';
import { AttachmentStatusIcon } from './AttachmentStatusIcon';

import type { LocalizerType } from '../../types/Util';
import type { EmbeddedContactType } from '../../types/EmbeddedContact';
import { isPermanentlyUndownloadable } from '../../types/Attachment';

export function renderAvatar({
  contact,
  direction,
  i18n,
  size,
}: {
  contact: ReadonlyDeep<EmbeddedContactType>;
  direction?: 'outgoing' | 'incoming';
  i18n: LocalizerType;
  size: 52 | 80;
}): JSX.Element {
  const { avatar } = contact;

  const avatarUrl = avatar && avatar.avatar && avatar.avatar.path;
  const title = getName(contact) || '';
  const isAttachmentNotAvailable = Boolean(
    avatar?.avatar && isPermanentlyUndownloadable(avatar?.avatar)
  );

  const renderAttachmentDownloaded = () => (
    <Avatar
      acceptedMessageRequest={false}
      avatarUrl={avatarUrl}
      badge={undefined}
      blur={AvatarBlur.NoBlur}
      color={AvatarColors[0]}
      conversationType="direct"
      i18n={i18n}
      isMe
      title={title}
      sharedGroupNames={[]}
      size={size}
    />
  );

  return (
    <AttachmentStatusIcon
      attachment={avatar?.avatar}
      isAttachmentNotAvailable={isAttachmentNotAvailable}
      isIncoming={direction === 'incoming'}
      renderAttachmentDownloaded={renderAttachmentDownloaded}
    />
  );
}

export function renderName({
  contact,
  isIncoming,
  module,
}: {
  contact: ReadonlyDeep<EmbeddedContactType>;
  isIncoming: boolean;
  module: string;
}): JSX.Element {
  return (
    <div
      className={classNames(
        `module-${module}__contact-name`,
        isIncoming ? `module-${module}__contact-name--incoming` : null
      )}
    >
      {getName(contact)}
    </div>
  );
}

export function renderContactShorthand({
  contact,
  isIncoming,
  module,
}: {
  contact: ReadonlyDeep<EmbeddedContactType>;
  isIncoming: boolean;
  module: string;
}): JSX.Element {
  const { number: phoneNumber, email } = contact;
  const firstNumber = phoneNumber && phoneNumber[0] && phoneNumber[0].value;
  const firstEmail = email && email[0] && email[0].value;

  return (
    <div
      className={classNames(
        `module-${module}__contact-method`,
        isIncoming ? `module-${module}__contact-method--incoming` : null
      )}
    >
      {firstNumber || firstEmail}
    </div>
  );
}
